import { childProcessExec } from "../adapters/childProcessExec.js";
import { fsFileSystem } from "../adapters/fsFileSystem.js";
import { globAsync } from "../adapters/globAsync.js";
import { nativeImporter } from "../adapters/nativeImporter.js";
import { processLogger } from "../adapters/processLogger.js";
import { bind } from "../binding.js";
import { collectCommentFileNames, } from "../comments/collectCommentFileNames.js";
import { convertComments, } from "../converters/comments/convertComments.js";
import { convertFileComments, } from "../converters/comments/convertFileComments.js";
import { extractGlobPaths, } from "../converters/comments/extractGlobPaths.js";
import { reportCommentResults, } from "../converters/comments/reporting/reportCommentResults.js";
import { convertEditorConfig, } from "../converters/editorConfigs/convertEditorConfig.js";
import { convertEditorConfigs, } from "../converters/editorConfigs/convertEditorConfigs.js";
import { convertAtomConfig } from "../converters/editorConfigs/converters/convertAtomConfig.js";
import { convertVSCodeConfig } from "../converters/editorConfigs/converters/convertVSCodeConfig.js";
import { reportEditorConfigConversionResults } from "../converters/editorConfigs/reporting/reportEditorConfigConversionResults.js";
import { convertLintConfig, } from "../converters/lintConfigs/convertLintConfig.js";
import { createESLintConfiguration, } from "../converters/lintConfigs/createESLintConfiguration.js";
import { removeExtendsDuplicatedRules } from "../converters/lintConfigs/pruning/removeExtendsDuplicatedRules.js";
import { choosePackageManager, } from "../converters/lintConfigs/reporting/packages/choosePackageManager.js";
import { logMissingPackages, } from "../converters/lintConfigs/reporting/packages/logMissingPackages.js";
import { reportConfigConversionResults, } from "../converters/lintConfigs/reporting/reportConfigConversionResults.js";
import { convertRules, } from "../converters/lintConfigs/rules/convertRules.js";
import { ruleConverters } from "../converters/lintConfigs/rules/ruleConverters.js";
import { ruleMergers } from "../converters/lintConfigs/rules/ruleMergers.js";
import { checkPrettierExtension } from "../converters/lintConfigs/summarization/prettier/checkPrettierExtension.js";
import { retrieveExtendsValues, } from "../converters/lintConfigs/summarization/retrieveExtendsValues.js";
import { summarizePackageRules, } from "../converters/lintConfigs/summarization/summarizePackageRules.js";
import { findESLintConfiguration } from "../input/findESLintConfiguration.js";
import { findOriginalConfigurations, } from "../input/findOriginalConfigurations.js";
import { findPackagesConfiguration } from "../input/findPackagesConfiguration.js";
import { findTSLintConfiguration } from "../input/findTSLintConfiguration.js";
import { findTypeScriptConfiguration } from "../input/findTypeScriptConfiguration.js";
import { importer } from "../input/importer.js";
import { mergeLintConfigurations } from "../input/mergeLintConfigurations.js";
export const convertFileCommentsDependencies = {
    converters: ruleConverters,
    fileSystem: fsFileSystem,
};
export const reportCommentResultsDependencies = {
    logger: processLogger,
};
export const convertRulesDependencies = {
    ruleConverters,
    ruleMergers,
};
export const nativeImporterDependencies = {
    fileSystem: fsFileSystem,
    getCwd: () => process.cwd(),
    nativeImporter: nativeImporter,
};
export const boundImporter = bind(importer, nativeImporterDependencies);
export const findConfigurationDependencies = {
    exec: childProcessExec,
    importer: boundImporter,
    platform: process.platform,
};
export const findOriginalConfigurationsDependencies = {
    findESLintConfiguration: bind(findESLintConfiguration, findConfigurationDependencies),
    findPackagesConfiguration: bind(findPackagesConfiguration, findConfigurationDependencies),
    findTypeScriptConfiguration: bind(findTypeScriptConfiguration, findConfigurationDependencies),
    findTSLintConfiguration: bind(findTSLintConfiguration, findConfigurationDependencies),
    mergeLintConfigurations,
};
export const collectCommentFileNamesDependencies = {
    findTypeScriptConfiguration: bind(findTypeScriptConfiguration, findConfigurationDependencies),
};
export const extractGlobPathsDependencies = {
    globAsync,
};
export const convertCommentsDependencies = {
    collectCommentFileNames: bind(collectCommentFileNames, collectCommentFileNamesDependencies),
    convertFileComments: bind(convertFileComments, convertFileCommentsDependencies),
    extractGlobPaths: bind(extractGlobPaths, extractGlobPathsDependencies),
    reportCommentResults: bind(reportCommentResults, reportCommentResultsDependencies),
};
export const retrieveExtendsValuesDependencies = {
    importer: boundImporter,
};
export const summarizePackageRulesDependencies = {
    checkPrettierExtension,
    removeExtendsDuplicatedRules,
    retrieveExtendsValues: bind(retrieveExtendsValues, retrieveExtendsValuesDependencies),
};
export const choosePackageManagerDependencies = {
    fileSystem: fsFileSystem,
};
export const createESLintConfigurationDependencies = {
    convertRules: bind(convertRules, convertRulesDependencies),
    summarizePackageRules: bind(summarizePackageRules, summarizePackageRulesDependencies),
};
export const logMissingPackagesDependencies = {
    choosePackageManager: bind(choosePackageManager, choosePackageManagerDependencies),
    logger: processLogger,
};
export const reportConversionResultsDependencies = {
    logger: processLogger,
};
export const reportEditorSettingConversionResultsDependencies = {
    logger: processLogger,
};
export const writeConversionResultsDependencies = {
    fileSystem: fsFileSystem,
};
export const convertEditorConfigDependencies = {
    fileSystem: fsFileSystem,
};
export const editorConfigDescriptors = [
    [".atom/config.cson", convertAtomConfig],
    [".vscode/settings.json", convertVSCodeConfig],
];
export const reportEditorConfigConversionResultsDependencies = {
    logger: processLogger,
};
export const convertEditorConfigsDependencies = {
    convertEditorConfig: bind(convertEditorConfig, convertEditorConfigDependencies),
    editorConfigDescriptors,
    reportEditorConfigConversionResults: bind(reportEditorConfigConversionResults, reportEditorConfigConversionResultsDependencies),
};
export const convertLintConfigDependencies = {
    createESLintConfiguration: bind(createESLintConfiguration, createESLintConfigurationDependencies),
    fileSystem: fsFileSystem,
    logMissingPackages: bind(logMissingPackages, logMissingPackagesDependencies),
    reportConfigConversionResults: bind(reportConfigConversionResults, reportConversionResultsDependencies),
};
export const runCliDependencies = {
    converters: [
        bind(convertLintConfig, convertLintConfigDependencies),
        bind(convertEditorConfigs, convertEditorConfigsDependencies),
        bind(convertComments, convertCommentsDependencies),
    ],
    findOriginalConfigurations: bind(findOriginalConfigurations, findOriginalConfigurationsDependencies),
    logger: processLogger,
};
//# sourceMappingURL=dependencies.js.map