import { FileSystem } from "../../adapters/fileSystem.js";
import { SansDependencies } from "../../binding.js";
import { AllOriginalConfigurations } from "../../input/findOriginalConfigurations.js";
import { ResultWithStatus, TSLintToESLintSettings } from "../../types.js";
import { createESLintConfiguration } from "./createESLintConfiguration.js";
import { logMissingPackages } from "./reporting/packages/logMissingPackages.js";
import { reportConfigConversionResults } from "./reporting/reportConfigConversionResults.js";
export declare type ConvertLintConfigDependencies = {
    createESLintConfiguration: SansDependencies<typeof createESLintConfiguration>;
    fileSystem: Pick<FileSystem, "writeFile">;
    logMissingPackages: SansDependencies<typeof logMissingPackages>;
    reportConfigConversionResults: SansDependencies<typeof reportConfigConversionResults>;
};
/**
 * Root-level driver to convert a TSLint configuration to ESLint.
 * @see `/docs/Architecture/Linters.md` for documentation.
 */
export declare const convertLintConfig: (dependencies: ConvertLintConfigDependencies, settings: TSLintToESLintSettings, originalConfigurations: AllOriginalConfigurations, ruleEquivalents: Map<string, string[]>) => Promise<ResultWithStatus>;
