import { SansDependencies } from "../binding.js";
import { ConfigurationErrorResult, ConfigurationLocations, SucceededDataResult } from "../types.js";
import { ESLintConfiguration, findESLintConfiguration } from "./findESLintConfiguration.js";
import { findPackagesConfiguration, PackagesConfiguration } from "./findPackagesConfiguration.js";
import { DeepPartial } from "./findReportedConfiguration.js";
import { findTSLintConfiguration, TSLintConfiguration } from "./findTSLintConfiguration.js";
import { findTypeScriptConfiguration, TypeScriptConfiguration } from "./findTypeScriptConfiguration.js";
import { mergeLintConfigurations } from "./mergeLintConfigurations.js";
export declare type FindOriginalConfigurationsDependencies = {
    findESLintConfiguration: SansDependencies<typeof findESLintConfiguration>;
    findPackagesConfiguration: SansDependencies<typeof findPackagesConfiguration>;
    findTypeScriptConfiguration: SansDependencies<typeof findTypeScriptConfiguration>;
    findTSLintConfiguration: SansDependencies<typeof findTSLintConfiguration>;
    mergeLintConfigurations: typeof mergeLintConfigurations;
};
/**
 * Both found configurations for a particular linter.
 */
export declare type OriginalConfigurations<Configuration> = {
    /**
     * Settings reported by the linter's native --print-config equivalent.
     */
    full: Configuration;
    /**
     * Raw import results from `import`ing the configuration file.
     */
    raw: DeepPartial<Configuration>;
};
export declare type AllOriginalConfigurations = {
    eslint?: OriginalConfigurations<ESLintConfiguration>;
    packages?: PackagesConfiguration;
    tslint: OriginalConfigurations<TSLintConfiguration>;
    typescript?: TypeScriptConfiguration;
};
/**
 * Searches for all relevant input configurations on disk.
 */
export declare const findOriginalConfigurations: (dependencies: FindOriginalConfigurationsDependencies, locations: ConfigurationLocations) => Promise<ConfigurationErrorResult | SucceededDataResult<AllOriginalConfigurations>>;
